@@ -231,7 +231,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -1177,8 +1177,7 @@ class FooType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.FooType = FooType_member
-        if self.FooType is not None:
-            self.validate_FooTypeType(self.FooType)
+        self.validate_FooTypeType(self.FooType)
         self.FooType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1296,8 +1295,7 @@ class BarType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.BarType = BarType_member
-        if self.BarType is not None:
-            self.validate_BarTypeType(self.BarType)
+        self.validate_BarTypeType(self.BarType)
         self.BarType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1415,8 +1413,7 @@ class BazType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.BazType = BazType_member
-        if self.BazType is not None:
-            self.validate_BazTypeType(self.BazType)
+        self.validate_BazTypeType(self.BazType)
         self.BazType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
