@@ -83,6 +83,8 @@ $commands = [
   "diff -u preserve_cdata_tags1_sup.py preserve_cdata_tags2_sup.py",
   "diff -u decimal_format1_sub.py decimal_format2_sub.py",
   "diff -u decimal_format1_sup.py decimal_format2_sup.py",
+  "diff -u derived_types1_sub.py derived_types2_sub.py",
+  "diff -u derived_types1_sup.py derived_types2_sup.py",
 ]
 
 def check
