@@ -1059,7 +1059,7 @@ class animalCollection(GeneratedsSuper):
         else:
             eol_ = ''
         for animal_ in self.animal:
-            animal_.export(outfile, level, namespaceprefix_, namespacedef_='', pretty_print=pretty_print)
+            animal_.export(outfile, level, namespaceprefix_, name_='animal', namespacedef_='', pretty_print=pretty_print)
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
