@@ -102,10 +102,9 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd, cwd=TEST_DIR)
         if sys.version_info.major != 2:
             result = result.decode()
-        self.assertEqual(result, """\
+        self.assertEqual(result.splitlines(), """\
 ['node1node1', 'group1', 'group2', 'node1node2']
-['node2node1', 'group1', 'group2', 'node2node2']
-""")
+['node2node1', 'group1', 'group2', 'node2node2']""".splitlines())
         # load the XML, and verify the proper data was loaded
         cmdTempl = (
             'python3 -c "import %s_sub; obj = '
@@ -119,10 +118,9 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd, cwd=TEST_DIR)
         if sys.version_info.major != 2:
             result = result.decode()
-        self.assertEqual(result, """\
+        self.assertEqual(result.splitlines(), """\
 ['value 1 1', 'group1 1', 'group2 1', 'value 1 2']
-['value 2 1', 'group1 2', 'group2 2', 'value 2 2']
-""")
+['value 2 1', 'group1 2', 'group2 2', 'value 2 2']""".splitlines())
         # cleanup generated files
         self.remove('{}_sup.py'.format(t_))
         self.remove('{}_sub.py'.format(t_))
@@ -153,9 +151,8 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd, cwd=TEST_DIR)
         if sys.version_info.major != 2:
             result = result.decode()
-        self.assertEqual(result, """\
-[('child1', 'value1'), ('child1', 'value2')]
-""")
+        self.assertEqual(result.splitlines(), """\
+[('child1', 'value1'), ('child1', 'value2')]""".splitlines())
         # Now try to create a node, make sure the value of valueOf_ is passed
         # in
         # Run these commands::
@@ -176,9 +173,8 @@ class GenTest(unittest.TestCase):
         #print('result: %s' % result)
         if sys.version_info.major != 2:
             result = result.decode()
-        self.assertEqual(result, """\
-('child1', 'value1')
-""")
+        self.assertEqual(result.splitlines(), """\
+('child1', 'value1')""".splitlines())
         # cleanup generated files
         self.remove('{}_sup.py'.format(t_))
         self.remove('{}_sub.py'.format(t_))
