@@ -230,7 +230,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -1411,8 +1411,7 @@ class USAddress(Address):
         self.ns_prefix_ = None
         super(USAddress, self).__init__(name, street, city,  **kwargs_)
         self.state = state
-        if self.state is not None:
-            self.validate_USState(self.state)
+        self.validate_USState(self.state)
         self.state_nsprefix_ = None
         self.zip = zip
         self.zip_nsprefix_ = None
@@ -1554,8 +1553,7 @@ class UKAddress(Address):
         self.exportCode = _cast(int, exportCode)
         self.exportCode_nsprefix_ = None
         self.postcode = postcode
-        if self.postcode is not None:
-            self.validate_UKPostcode(self.postcode)
+        self.validate_UKPostcode(self.postcode)
         self.postcode_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1694,8 +1692,7 @@ class itemType(GeneratedsSuper):
         self.productName = productName
         self.productName_nsprefix_ = None
         self.quantity = quantity
-        if self.quantity is not None:
-            self.validate_quantityType(self.quantity)
+        self.validate_quantityType(self.quantity)
         self.quantity_nsprefix_ = None
         self.USPrice = USPrice
         self.USPrice_nsprefix_ = None
